@@ -90,7 +90,7 @@ def main(argv: Optional[List[str]] = None, logger: Optional[logging.Logger] = No
         make_output_directory(args.output_dir, args.force, args.nodelete)
 
     # connect to the local CAZyme database
-    connection, logger_name, cache_dir = cazy_scraper.connect_existing_db(args, time_stamp)
+    connection, logger_name, cache_dir = cazy_scraper.connect_existing_db(args, time_stamp, start_time)
     # make cache_dir
     make_output_directory(cache_dir, args.force_cache, args.nodelete_cache)
 
